#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Interfaces for ingest_envoy
"""
import abc
from abc import ABC

from ingest_envoy.schema import AbstractTextFile


class IngestLauncherIF(ABC):
    """
    Generic Ingestion Launcher methods.
    Should be implemented for any type of ingestion launcher
    """

    # launch all ingest steps, should be called in ingest.main
    @abc.abstractmethod
    def launch_ingestion(self):
        pass

    # setup workflow results for ingestion, ensure placement in staging area
    @abc.abstractmethod
    def prepare_for_ingest(self):
        pass

    # create ingestion manifest
    @abc.abstractmethod
    def create_manifest(self, additional_file: AbstractTextFile = None):
        pass
